@@ -1,7 +1,7 @@
 package Finance::Bank::ID::BCA;
 
-our $DATE = '2017-05-15'; # DATE
-our $VERSION = '0.44'; # VERSION
+our $DATE = '2017-05-16'; # DATE
+our $VERSION = '0.45'; # VERSION
 
 use 5.010001;
 use Moo;
@@ -11,8 +11,6 @@ use Log::Any::IfLOG '$log';
 extends 'Finance::Bank::ID::Base';
 
 has _variant => (is => 'rw'); # bisnis or perorangan
-has skip_NEXT => (is => 'rw');
-has skip_problematic => (is => 'rw');
 
 sub BUILD {
     my ($self, $args) = @_;
@@ -420,15 +418,7 @@ sub _ps_get_transactions {
             # month, regardless of whether it's Sat/Sun or not
         }
 
-        if ($tx->{is_next} && ($self->skip_NEXT || $self->skip_problematic)) {
-            push @skipped_tx, $tx;
-            $seq--;
-        } elsif ($tx->{is_pending} && $tx->{description} eq 'SETORAN KLIRING BI' && ($self->skip_NEXT || $self->skip_problematic)) {
-            push @skipped_tx, $tx;
-            $seq--;
-        } else {
-            push @tx, $tx;
-        }
+        push @tx, $tx;
     }
     $stmt->{transactions} = \@tx;
     $stmt->{skipped_transactions} = \@skipped_tx;
@@ -450,7 +440,7 @@ Finance::Bank::ID::BCA - Check your BCA accounts from Perl
 
 =head1 VERSION
 
-This document describes version 0.44 of Finance::Bank::ID::BCA (from Perl distribution Finance-Bank-ID-BCA), released on 2017-05-15.
+This document describes version 0.45 of Finance::Bank::ID::BCA (from Perl distribution Finance-Bank-ID-BCA), released on 2017-05-16.
 
 =head1 SYNOPSIS
 
@@ -545,22 +535,6 @@ in the distribution.
 
 =head1 ATTRIBUTES
 
-=head2 skip_NEXT => BOOL
-
-If set to true, then entries with NEXT status will be skipped.
-
-See also: C<skip_problematic>.
-
-=head2 skip_problematic => BOOL
-
-If set to true, will skip entries that are problematic, i.e. that might change
-or disappear in subsequent statement. For example: "SETORAN KLIRING BI" entries
-which can later show up at the top/bottom of statement.
-
-Will also skip NEXT entries.
-
-See also: C<skip_NEXT>.
-
 =head1 METHODS
 
 =for Pod::Coverage BUILD
